import { LitElement } from 'lit';
import { ComposedEvent } from '@patternfly/pfe-core';
export declare class ModalCancelEvent extends ComposedEvent {
    constructor();
}
export declare class ModalCloseEvent extends ComposedEvent {
    constructor();
}
export declare class ModalOpenEvent extends ComposedEvent {
    /** The trigger element which triggered the modal to open */
    trigger: HTMLElement | null;
    constructor(
    /** The trigger element which triggered the modal to open */
    trigger: HTMLElement | null);
}
/**
 * Modals display information in a window or help a user focus on a task without navigating them away from the page.
 * A user can’t perform other actions until the modal is dismissed.
 *
 * @summary Displays information or helps a user focus on a task
 *
 * @csspart overlay - The modal overlay which lies under the dialog and above the page body
 * @csspart dialog - The dialog element
 * @csspart content - The container for the dialog content
 * @csspart close-button - The modal's close button
 *
 * @fires {ModalOpenEvent} open - Fires when a user clicks on the trigger or manually opens a modal.
 * @fires {ModalCloseEvent} close - Fires when either a user clicks on either the close button or the overlay or manually closes a modal.
 *
 * @fires {CustomEvent<{ open: true; trigger?: HTMLElement }>} pfe-modal:open - {@deprecated Use `open`} When the modal opens
 * @fires {CustomEvent<{ open: false }>} pfe-modal:close - {@deprecated Use `close`} When the modal closes
 * @slot - The default slot can contain any type of content. When the header is not present this unnamed slot appear at the top of the modal window (to the left of the close button). Otherwise it will appear beneath the header.
 * @slot trigger - The only part visible on page load, the trigger opens the modal window. The trigger can be a button, a cta or a link. While it is part of the modal web component, it does not contain any intrinsic styles.
 * @slot header - The header is an optional slot that appears at the top of the modal window. It should be a header tag (h2-h6).
 * @slot pfe-modal--trigger - {@deprecated use `trigger`}
 * @slot pfe-modal--header - {@deprecated use `header`}
 */
export declare class PfeModal extends LitElement {
    static readonly shadowRootOptions: {
        delegatesFocus: boolean;
        mode: ShadowRootMode;
        slotAssignment?: SlotAssignmentMode | undefined;
        customElements?: CustomElementRegistry | undefined;
    };
    static readonly version = "{{version}}";
    static readonly styles: import("lit").CSSResult[];
    /**
     * The `width` controls the width of the modal.
     * There are three options: `small`, `medium` and `large`. The default is `large`.
     */
    width: 'small' | 'medium' | 'large';
    open: boolean;
    /** Optional ID of the trigger element */
    trigger?: string;
    returnValue?: string;
    private overlay?;
    private dialog?;
    private _modalCloseButton?;
    private headerId;
    private triggerElement;
    private header;
    private body;
    private headings;
    private cancelling;
    private slots;
    connectedCallback(): void;
    render(): import("lit-html").TemplateResult<1>;
    disconnectedCallback(): void;
    protected _init(): Promise<void>;
    protected _triggerChanged(): void;
    private onExternalTriggerClick;
    private onClick;
    private _keydownHandler;
    private cancel;
    protected _openChanged(oldValue?: boolean, newValue?: boolean): Promise<void>;
    setTrigger(element: HTMLElement): void;
    /**
     * Manually toggles a modal.
     * ```javascript
     * document.querySelector('pfe-modal').toggle();
     * ```
     */
    toggle(): void;
    /**
     * Manually opens a modal.
     * ```javascript
     * document.querySelector('pfe-modal').open();
     * ```
     */
    show(): void;
    showModal(): void;
    /**
     * Manually closes a modal.
     * ```javascript
     * document.querySelector('pfe-modal').close();
     * ```
     */
    close(returnValue?: string): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'pfe-modal': PfeModal;
    }
}
